==> blanco.plugin.logmessage_0.0.1-src.zip: src/blanco/logmessage/task/valueobject/BlancoLogMessageProcessInput.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.logmessage.task.valueobject;

/**
 * NX [BlancoLogMessageProcess]̓̓o[IuWFNgNXłB
 */
public class BlancoLogMessageProcessInput {
    /**
     * tB[h [verbose]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     */
    private boolean fVerbose = false;

    /**
     * tB[h [metadir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^fBNgBxlst@C̊i[܂ xmlt@C̊i[w肵܂B
     */
    private String fMetadir;

    /**
     * tB[h [targetdir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [blanco]<br>
     * o͐tH_w肵܂Bw̏ꍇɂ̓Jgblancop܂B
     */
    private String fTargetdir = "blanco";

    /**
     * tB[h [tmpdir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [tmp]<br>
     * e|fBNgw肵܂Bw̏ꍇɂ̓Jgtmpp܂B
     */
    private String fTmpdir = "tmp";

    /**
     * tB[h [targetlang]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [java]<br>
     * ^[QbgƂȂvO~OꏈnBJava ̂ݑΉBΉ cs, js, vb,php,ruby,pythonB
     */
    private String fTargetlang = "java";

    /**
     * tB[h [verbose]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * verbose[hœ삳邩ǂB
     *
     * @param argVerbose tB[h[verbose]Ɋi[l
     */
    public void setVerbose(final boolean argVerbose) {
        fVerbose = argVerbose;
    }

    /**
     * tB[h[verbose]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     *
     * @return tB[h[verbose]Ɋi[Ăl
     */
    public boolean getVerbose() {
        return fVerbose;
    }

    /**
     * tB[h [metadir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^fBNgBxlst@C̊i[܂ xmlt@C̊i[w肵܂B
     *
     * @param argMetadir tB[h[metadir]Ɋi[l
     */
    public void setMetadir(final String argMetadir) {
        fMetadir = argMetadir;
    }

    /**
     * tB[h[metadir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^fBNgBxlst@C̊i[܂ xmlt@C̊i[w肵܂B
     *
     * @return tB[h[metadir]Ɋi[Ăl
     */
    public String getMetadir() {
        return fMetadir;
    }

    /**
     * tB[h [targetdir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o͐tH_w肵܂Bw̏ꍇɂ̓Jgblancop܂B
     *
     * @param argTargetdir tB[h[targetdir]Ɋi[l
     */
    public void setTargetdir(final String argTargetdir) {
        fTargetdir = argTargetdir;
    }

    /**
     * tB[h[targetdir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [blanco]<br>
     * o͐tH_w肵܂Bw̏ꍇɂ̓Jgblancop܂B
     *
     * @return tB[h[targetdir]Ɋi[Ăl
     */
    public String getTargetdir() {
        return fTargetdir;
    }

    /**
     * tB[h [tmpdir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * e|fBNgw肵܂Bw̏ꍇɂ̓Jgtmpp܂B
     *
     * @param argTmpdir tB[h[tmpdir]Ɋi[l
     */
    public void setTmpdir(final String argTmpdir) {
        fTmpdir = argTmpdir;
    }

    /**
     * tB[h[tmpdir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [tmp]<br>
     * e|fBNgw肵܂Bw̏ꍇɂ̓Jgtmpp܂B
     *
     * @return tB[h[tmpdir]Ɋi[Ăl
     */
    public String getTmpdir() {
        return fTmpdir;
    }

    /**
     * tB[h [targetlang]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^[QbgƂȂvO~OꏈnBJava ̂ݑΉBΉ cs, js, vb,php,ruby,pythonB
     *
     * @param argTargetlang tB[h[targetlang]Ɋi[l
     */
    public void setTargetlang(final String argTargetlang) {
        fTargetlang = argTargetlang;
    }

    /**
     * tB[h[targetlang]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [java]<br>
     * ^[QbgƂȂvO~OꏈnBJava ̂ݑΉBΉ cs, js, vb,php,ruby,pythonB
     *
     * @return tB[h[targetlang]Ɋi[Ăl
     */
    public String getTargetlang() {
        return fTargetlang;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.logmessage.task.valueobject.BlancoLogMessageProcessInput[");
        buf.append("verbose=" + fVerbose);
        buf.append(",metadir=" + fMetadir);
        buf.append(",targetdir=" + fTargetdir);
        buf.append(",tmpdir=" + fTmpdir);
        buf.append(",targetlang=" + fTargetlang);
        buf.append("]");
        return buf.toString();
    }
}

==> blanco.plugin.logmessage_0.0.3-src.zip: src/blanco/logmessage/task/valueobject/BlancoLogMessageProcessInput.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.logmessage.task.valueobject;

/**
 * NX [BlancoLogMessageProcess]̓̓o[IuWFNgNXłB
 */
public class BlancoLogMessageProcessInput {
    /**
     * tB[h [verbose]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     */
    private boolean fVerbose = false;

    /**
     * tB[h [metadir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^fBNgBxlst@C̊i[܂ xmlt@C̊i[w肵܂B
     */
    private String fMetadir;

    /**
     * tB[h [targetdir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [blanco]<br>
     * o͐tH_w肵܂Bw̏ꍇɂ̓Jgblancop܂B
     */
    private String fTargetdir = "blanco";

    /**
     * tB[h [tmpdir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [tmp]<br>
     * e|fBNgw肵܂Bw̏ꍇɂ̓Jgtmpp܂B
     */
    private String fTmpdir = "tmp";

    /**
     * tB[h [targetlang]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [java]<br>
     * ^[QbgƂȂvO~OꏈnBJava ̂ݑΉBΉ cs, js, vb,php,ruby,pythonB
     */
    private String fTargetlang = "java";

    /**
     * tB[h [targetLogger]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [java.util.logging]<br>
     * ^[QbgƂȂ郍K[Borg.apache.log4j w\B
     */
    private String fTargetLogger = "java.util.logging";

    /**
     * tB[h [verbose]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * verbose[hœ삳邩ǂB
     *
     * @param argVerbose tB[h[verbose]Ɋi[l
     */
    public void setVerbose(final boolean argVerbose) {
        fVerbose = argVerbose;
    }

    /**
     * tB[h[verbose]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     *
     * @return tB[h[verbose]Ɋi[Ăl
     */
    public boolean getVerbose() {
        return fVerbose;
    }

    /**
     * tB[h [metadir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^fBNgBxlst@C̊i[܂ xmlt@C̊i[w肵܂B
     *
     * @param argMetadir tB[h[metadir]Ɋi[l
     */
    public void setMetadir(final String argMetadir) {
        fMetadir = argMetadir;
    }

    /**
     * tB[h[metadir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^fBNgBxlst@C̊i[܂ xmlt@C̊i[w肵܂B
     *
     * @return tB[h[metadir]Ɋi[Ăl
     */
    public String getMetadir() {
        return fMetadir;
    }

    /**
     * tB[h [targetdir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o͐tH_w肵܂Bw̏ꍇɂ̓Jgblancop܂B
     *
     * @param argTargetdir tB[h[targetdir]Ɋi[l
     */
    public void setTargetdir(final String argTargetdir) {
        fTargetdir = argTargetdir;
    }

    /**
     * tB[h[targetdir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [blanco]<br>
     * o͐tH_w肵܂Bw̏ꍇɂ̓Jgblancop܂B
     *
     * @return tB[h[targetdir]Ɋi[Ăl
     */
    public String getTargetdir() {
        return fTargetdir;
    }

    /**
     * tB[h [tmpdir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * e|fBNgw肵܂Bw̏ꍇɂ̓Jgtmpp܂B
     *
     * @param argTmpdir tB[h[tmpdir]Ɋi[l
     */
    public void setTmpdir(final String argTmpdir) {
        fTmpdir = argTmpdir;
    }

    /**
     * tB[h[tmpdir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [tmp]<br>
     * e|fBNgw肵܂Bw̏ꍇɂ̓Jgtmpp܂B
     *
     * @return tB[h[tmpdir]Ɋi[Ăl
     */
    public String getTmpdir() {
        return fTmpdir;
    }

    /**
     * tB[h [targetlang]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^[QbgƂȂvO~OꏈnBJava ̂ݑΉBΉ cs, js, vb,php,ruby,pythonB
     *
     * @param argTargetlang tB[h[targetlang]Ɋi[l
     */
    public void setTargetlang(final String argTargetlang) {
        fTargetlang = argTargetlang;
    }

    /**
     * tB[h[targetlang]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [java]<br>
     * ^[QbgƂȂvO~OꏈnBJava ̂ݑΉBΉ cs, js, vb,php,ruby,pythonB
     *
     * @return tB[h[targetlang]Ɋi[Ăl
     */
    public String getTargetlang() {
        return fTargetlang;
    }

    /**
     * tB[h [targetLogger]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^[QbgƂȂ郍K[Borg.apache.log4j w\B
     *
     * @param argTargetLogger tB[h[targetLogger]Ɋi[l
     */
    public void setTargetLogger(final String argTargetLogger) {
        fTargetLogger = argTargetLogger;
    }

    /**
     * tB[h[targetLogger]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [java.util.logging]<br>
     * ^[QbgƂȂ郍K[Borg.apache.log4j w\B
     *
     * @return tB[h[targetLogger]Ɋi[Ăl
     */
    public String getTargetLogger() {
        return fTargetLogger;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.logmessage.task.valueobject.BlancoLogMessageProcessInput[");
        buf.append("verbose=" + fVerbose);
        buf.append(",metadir=" + fMetadir);
        buf.append(",targetdir=" + fTargetdir);
        buf.append(",tmpdir=" + fTmpdir);
        buf.append(",targetlang=" + fTargetlang);
        buf.append(",targetLogger=" + fTargetLogger);
        buf.append("]");
        return buf.toString();
    }
}
